---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
Please give a clear and concise description of the bug. For us to be able to
fix the bug we need to be able to reproduce it. As a result, if you provide a
reproducer, i.e. code that exhibits the bug (incl. build instructions) but is
stripped of all unessential complexity, the chance of getting the issue fixed
is much higher.

**Version Information**
  - HighFive:
  - Compiler:
  - [optional] OS:
  - [optional] CMake:
  - [optional] HDF5:

**Style Guide**
1. Please paste text as text and not as a screen shot.
2. If in doubt paste too much output rather than too little, i.e. don't be too
   scared of a large wall of text. Especially, if it's a compiler error.
   (Anything past the first error is largely uninformative and can be safely
   stripped.)
3. Please strip all boilerplate.

**Markdown summary**
Some include `code` and a block:
```
void foo();
```

